@@ -9,11 +9,12 @@ from signalfx_tracing import auto_instrument, create_tracer
 from signalfx_tracing.utils import get_module, TracerProxy
 
 
-access_token = os.environ.get('SIGNALFX_ACCESS_TOKEN')
+access_token = os.environ.get("SIGNALFX_ACCESS_TOKEN")
 
 
 def create_celery_tracer():
     import opentracing
+
     tracer_proxy = TracerProxy()
     opentracing.tracer = tracer_proxy
     auto_instrument(tracer_proxy)
@@ -26,7 +27,11 @@ def create_celery_tracer():
         tracer_proxy.set_tracer(tracer)
 
 
-if hasattr(sys, 'argv') and sys.argv[0].split(os.path.sep)[-1] == 'celery' and 'worker' in sys.argv:
+if (
+    hasattr(sys, "argv")
+    and sys.argv[0].split(os.path.sep)[-1] == "celery"
+    and "worker" in sys.argv
+):
     create_celery_tracer()
 else:
     try:
@@ -40,10 +45,10 @@ else:
 
 # Removing references to this sitecustomize module
 # can trigger garbage collection and cause lookup failures in other modules.
-sys.modules['sfx_sitecustomize'] = sys.modules.pop('sitecustomize', None)
+sys.modules["sfx_sitecustomize"] = sys.modules.pop("sitecustomize", None)
 sys.path.remove(os.path.abspath(os.path.dirname(__file__)))
 
 # Attempt to load any existing sitecustomize
-module = get_module('sitecustomize')
+module = get_module("sitecustomize")
 if module is None:  # reset to our own if no preexisting
-    sys.modules['sitecustomize'] = sys.modules['sfx_sitecustomize']
+    sys.modules["sitecustomize"] = sys.modules["sfx_sitecustomize"]
