@@ -4,13 +4,16 @@ import traceback
 import opentracing
 from opentracing.ext import tags
 
+from signalfx_tracing.utils import padded_hex
+
 SCOPE_KEY = "_signalfx_scope_key"
 
 
 class TraceMiddleware(object):
-    def __init__(self, tracer=None, attributes=None):
+    def __init__(self, tracer=None, attributes=None, trace_response_header_enabled=False):
         self.tracer = tracer or opentracing.tracer
         self.attributes = attributes or []
+        self.trace_response_header_enabled = trace_response_header_enabled
 
     def process_request(self, req, resp):
         operation_name = req.path
@@ -41,9 +44,9 @@ class TraceMiddleware(object):
         if scope is None:
             return
         resource_name = resource.__class__.__name__
-        scope.span.set_tag('falcon.resource', resource_name)
+        scope.span.set_tag("falcon.resource", resource_name)
         scope.span.set_operation_name(
-            '{0}.on_{1}'.format(resource_name, req.method.lower())
+            "{0}.on_{1}".format(resource_name, req.method.lower())
         )
 
     def process_response(self, req, resp, resource, req_succeeded=None):
@@ -73,4 +76,16 @@ class TraceMiddleware(object):
                         )
 
         scope.span.set_tag(tags.HTTP_STATUS_CODE, status.split(" ")[0])
+
+        if self.trace_response_header_enabled:
+            trace_id = getattr(scope.span.context, "trace_id", 0)
+            span_id = getattr(scope.span.context, "span_id", 0)
+            if trace_id and span_id:
+                resp.append_header("Access-Control-Expose-Headers", "Server-Timing")
+                resp.append_header(
+                    "Server-Timing", 'traceparent;desc="00-{trace_id}-{span_id}-01"'.format(
+                        trace_id=padded_hex(trace_id),
+                        span_id=padded_hex(span_id),
+                    ),
+                )
         scope.close()
