@@ -22,6 +22,7 @@ def session_new(_, session_class, *args, **kwargs):
     """Monkey patch Session.__new__() to create a SessionTracing object"""
     from requests_opentracing import SessionTracing
     from requests.sessions import Session
+
     if session_class is Session:
         return SessionTracing.__new__(SessionTracing)
 
@@ -39,6 +40,7 @@ def session_new(_, session_class, *args, **kwargs):
 def session_tracing_new(_, __, *args, **kwargs):
     """Monkey patch a valid SessionTracing.__new__() to avoid recursion on patched base class"""
     from requests_opentracing import SessionTracing
+
     return object.__new__(SessionTracing)
 
 
@@ -49,13 +51,19 @@ def instrument(tracer=None):
     SessionTracing.__init__ is also wrapped for correct argument injection.
     """
 
-    requests = utils.get_module('requests')
+    requests = utils.get_module("requests")
     if utils.is_instrumented(requests):
         return
 
     def session_tracing_init(__init__, instance, args, kwargs):
         _tracer = tracer or config.tracer or opentracing.tracer
-        __init__(_tracer, propagate=config.propagate, span_tags=config.span_tags or {}, *args, **kwargs)
+        __init__(
+            _tracer,
+            propagate=config.propagate,
+            span_tags=config.span_tags or {},
+            *args,
+            **kwargs
+        )
 
     from requests_opentracing import SessionTracing
 
@@ -64,28 +72,30 @@ def instrument(tracer=None):
 
     SessionTracing.__new__ = session_tracing_new.__get__(SessionTracing)
     requests.Session.__new__ = session_new.__get__(requests.Session)
-    wrap_function_wrapper('requests_opentracing.tracing', 'SessionTracing.__init__', session_tracing_init)
+    wrap_function_wrapper(
+        "requests_opentracing.tracing", "SessionTracing.__init__", session_tracing_init
+    )
 
     utils.mark_instrumented(requests)
 
 
 def uninstrument():
-    requests = utils.get_module('requests')
+    requests = utils.get_module("requests")
     if not utils.is_instrumented(requests):
         return
 
     from requests_opentracing import SessionTracing
 
     if _session_tracing_new[0] is not None:
-        if hasattr(_session_tracing_new[0], '__get__'):
+        if hasattr(_session_tracing_new[0], "__get__"):
             SessionTracing.__new__ = _session_tracing_new[0].__get__(SessionTracing)
         else:  # builtin doesn't follow descriptor protocol
             SessionTracing.__new__ = _session_tracing_new[0]
     if _session_new[0] is not None:
-        if hasattr(_session_new[0], '__get__'):
+        if hasattr(_session_new[0], "__get__"):
             requests.Session.__new__ = _session_new[0].__get__(requests.Session)
         else:
             requests.Session.__new__ = _session_new[0]
 
-    utils.revert_wrapper(SessionTracing, '__init__')
+    utils.revert_wrapper(SessionTracing, "__init__")
     utils.mark_uninstrumented(requests)
