@@ -10,18 +10,18 @@ from signalfx_tracing import utils
 config = utils.Config(
     trace_all=True,
     trace_client=True,
-    traced_attributes=['path', 'method'],
+    traced_attributes=["path", "method"],
     start_span_cb=None,
     tracer=None,
 )
 
 
 def instrument(tracer=None):
-    tornado = utils.get_module('tornado')
+    tornado = utils.get_module("tornado")
     if utils.is_instrumented(tornado):
         return
 
-    tornado_opentracing = utils.get_module('tornado_opentracing')
+    tornado_opentracing = utils.get_module("tornado_opentracing")
 
     def _tracer_config(wrapped_tracer_config, _, wrapt_args, __):
         """
@@ -35,25 +35,28 @@ def instrument(tracer=None):
         kwargs = wrapt_args[3]
 
         _tracer = tracer or config.tracer or opentracing.tracer
-        kwargs['opentracing_tracing'] = tornado_opentracing.TornadoTracing(_tracer)
-        kwargs['opentracing_trace_all'] = config.trace_all
-        kwargs['opentracing_trace_client'] = config.trace_client
-        kwargs['opentracing_traced_attributes'] = config.traced_attributes
-        kwargs['opentracing_start_span_cb'] = config.start_span_cb
+        kwargs["opentracing_tracing"] = tornado_opentracing.TornadoTracing(_tracer)
+        kwargs["opentracing_trace_all"] = config.trace_all
+        kwargs["opentracing_trace_client"] = config.trace_client
+        kwargs["opentracing_traced_attributes"] = config.traced_attributes
+        kwargs["opentracing_start_span_cb"] = config.start_span_cb
+        kwargs["signalfx_trace_response_headers"] = utils.is_trace_response_header_enabled()
 
         wrapped_tracer_config(__init__, app, args, kwargs)
 
-    wrap_function_wrapper('tornado_opentracing.application', 'tracer_config', _tracer_config)
+    wrap_function_wrapper(
+        "tornado_opentracing.application", "tracer_config", _tracer_config
+    )
     tornado_opentracing.init_tracing()
     utils.mark_instrumented(tornado)
 
 
 def uninstrument():
-    tornado = utils.get_module('tornado')
+    tornado = utils.get_module("tornado")
     if not utils.is_instrumented(tornado):
         return
 
-    tornado_initialization = utils.get_module('tornado_opentracing.initialization')
+    tornado_initialization = utils.get_module("tornado_opentracing.initialization")
     tornado_initialization._unpatch_tornado()
     tornado_initialization._unpatch_tornado_client()
 
